﻿using Microsoft.ML;
using Microsoft.ML.Data;
using Microsoft.ML.Trainers;
using Microsoft.ML.Transforms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ChemicalContentTypeDetection
{
    class Program
    {
        static void Main(string[] args)
        {
            // 创建机器学习管道对象
            var pipeline = new LearningPipeline();
            // 读入样本数据
            pipeline.Add(new TextLoader("data.txt").CreateFrom<StructureData>());
            // 设置基于Label字段进行分类
            pipeline.Add(new Dictionarizer("Label"));
            // 设置Structure字段作为建模考虑因素
            pipeline.Add(new TextFeaturizer("Features", "Structure"));
            // 选择合适的数据分类器
            pipeline.Add(new StochasticDualCoordinateAscentClassifier());
            // 指定输出
            pipeline.Add(new PredictedLabelColumnOriginalValueConverter()
            {
                PredictedLabelColumn = "PredictedLabel"
            });
            // 基于样本数据训练模型
            var model = pipeline.Train<StructureData, PredictedData>();
            // 基于训练模型进行预测
            var prediction = model.Predict(new StructureData
            {
                Structure = "C(C(=O)COP(=O)(O)O)N"
            });
            // 输出预测结果
            Console.WriteLine(prediction.PredictedLabels);
        }
    }
}
